#! /usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const pkg_up_1 = __importDefault(require("pkg-up"));
const util_1 = require("util");
const child_process_1 = require("child_process");
const execFileAsync = (0, util_1.promisify)(child_process_1.execFile);
const monorepoRoot = path_1.default.resolve(__dirname, '..', '..');
async function main(fileList) {
    const filesToPrettify = [];
    await Promise.all(fileList.map(async (filePath) => {
        const packageJsonPath = await (0, pkg_up_1.default)({ cwd: path_1.default.dirname(filePath) });
        if (!packageJsonPath) {
            return;
        }
        const packageRoot = path_1.default.dirname(packageJsonPath);
        if (monorepoRoot === packageRoot) {
            return;
        }
        const packageJson = require(packageJsonPath);
        if (packageJson.scripts?.prettier) {
            filesToPrettify.push(filePath);
        }
    }));
    if (filesToPrettify.length === 0) {
        console.log('No files to re-format. Skipping ...');
        return;
    }
    console.log('Re-formatting following files ...');
    filesToPrettify.map((filePath) => {
        console.log(`  - ${path_1.default.relative(process.cwd(), filePath)}`);
    });
    await execFileAsync('npx', [
        'prettier',
        '--config',
        require.resolve('@mongodb-js/prettier-config-devtools/.prettierrc.json'),
        '--ignore-unknown',
        '--write',
        ...filesToPrettify,
    ]);
    await execFileAsync('git', ['add', ...filesToPrettify]);
}
const fileList = process.argv
    .slice(process.argv.findIndex((filename) => filename.includes('precommit')) + 1)
    .filter((arg) => !arg.startsWith('-'))
    .map((filePath) => {
    return path_1.default.resolve(process.cwd(), filePath);
});
main(fileList).catch((err) => process.nextTick(() => {
    throw err;
}));
//# sourceMappingURL=precommit.js.map