"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getHighestRange = exports.calculateReplacements = exports.intersects = void 0;
const semver_1 = __importDefault(require("semver"));
function intersects(range) {
    for (const [idx, v1] of Object.entries(range)) {
        for (const v2 of range.slice(Number(idx) + 1)) {
            try {
                if (!semver_1.default.intersects(v1, v2)) {
                    return false;
                }
            }
            catch (e) {
                return false;
            }
        }
    }
    return true;
}
exports.intersects = intersects;
function calculateReplacements(ranges) {
    const replacements = new Map();
    const highestRange = getHighestRange(ranges);
    for (const range of ranges) {
        try {
            if (semver_1.default.subset(highestRange ?? '', range)) {
                replacements.set(range, highestRange);
            }
        }
        catch (e) {
        }
    }
    return replacements;
}
exports.calculateReplacements = calculateReplacements;
function getHighestRange(ranges) {
    const validRanges = ranges.filter((range) => semver_1.default.validRange(range) && range !== '*');
    const sortedRanges = validRanges.sort((v1, v2) => {
        const res = semver_1.default.compare(semver_1.default.minVersion(v2) ?? '', semver_1.default.minVersion(v1) ?? '');
        if (res === 1 || res === -1) {
            return res;
        }
        if (semver_1.default.valid(v1) && !semver_1.default.valid(v2)) {
            return 1;
        }
        if (!semver_1.default.valid(v1) && semver_1.default.valid(v2)) {
            return -1;
        }
        return 0;
    });
    return sortedRanges[0] || null;
}
exports.getHighestRange = getHighestRange;
//# sourceMappingURL=semver-helpers.js.map