"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.collectWorkspacesDependencies = exports.collectWorkspacesMeta = void 0;
const path_1 = __importDefault(require("path"));
const get_packages_in_topological_order_1 = require("./get-packages-in-topological-order");
const find_monorepo_root_1 = require("./find-monorepo-root");
async function collectWorkspacesMeta() {
    const monorepoRoot = await (0, find_monorepo_root_1.findMonorepoRoot)();
    const workspaces = await (0, get_packages_in_topological_order_1.getPackagesInTopologicalOrder)(monorepoRoot);
    return new Map(workspaces
        .concat({ location: monorepoRoot })
        .map(({ location }) => [
        location,
        { ...require(path_1.default.join(location, 'package.json')), location },
    ]));
}
exports.collectWorkspacesMeta = collectWorkspacesMeta;
function getDepType(dependency, version, pkgJson) {
    return pkgJson.devDependencies &&
        pkgJson.devDependencies[dependency] === version
        ? 'dev'
        : pkgJson.peerDependencies &&
            pkgJson.peerDependencies[dependency] === version
            ? 'peer'
            : pkgJson.optionalDependencies &&
                pkgJson.optionalDependencies[dependency] === version
                ? 'optional'
                : pkgJson.dependencies && pkgJson.dependencies[dependency] === version
                    ? 'prod'
                    : null;
}
function collectWorkspacesDependencies(workspaces) {
    const dependencies = new Map();
    for (const [location, pkgJson] of workspaces) {
        for (const [dependency, versionRange] of [
            ...Object.entries(pkgJson.dependencies || {}),
            ...Object.entries(pkgJson.devDependencies || {}),
            ...filterOutStarDeps(Object.entries(pkgJson.peerDependencies || {})),
            ...filterOutStarDeps(Object.entries(pkgJson.optionalDependencies || {})),
        ]) {
            const item = {
                version: versionRange,
                workspace: pkgJson.name,
                from: location,
                type: getDepType(dependency, versionRange, pkgJson),
            };
            if (dependencies.has(dependency)) {
                dependencies.get(dependency).push(item);
            }
            else {
                dependencies.set(dependency, [item]);
            }
        }
    }
    return dependencies;
}
exports.collectWorkspacesDependencies = collectWorkspacesDependencies;
function filterOutStarDeps(entries) {
    return entries.filter(([, v]) => v !== '*');
}
//# sourceMappingURL=workspace-dependencies.js.map